Zingg model documentation

Cluster | z_score | fname | lname | stNo | add1 | add2 | city | areacode | state | dob | ssn | z_source | z_isMatch
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
1641598610941:16 | 1 | kiandra | cowle | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 1
| kiandra |  | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test |
1641598610941:14 | 1 | matilda | mestrov | 5 | house circuit | retirement village | taringa | 3820 | qld | 19801119 | 2563135 | test | 1
| matilda | mestrov | 5 | house circuit | retiremen tvillage | taringa | 3820 |  | 19801119 | 2563135 | test |
1641598610941:18 | 1 | jaiden | rollins | 48 | rossarden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 1
| jaiden | rollins | 48 | tulgeywood | rossarden street | balwyn north | 2224 | nt | 19280722 | 7626396 | test |
1641598078261:27 | 0 | kiandra | cowle | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 1
| kiandra |  | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test |
1641598610941:6 | 1 | jaiden | rollins | 48 | rossarden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 1
| jaiden | rolilns | 48 | swinden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test |
1641598610941:4 | 1 | tyler | froud | 8 | burramurra avenue | kmart p plaza | san remo | 3670 | sa | 19800916 | 7812219 | test | 1
| tyler | frojd |  | burramurra avenue | kmart p plaza | san rmeo | 3670 | sa | 19800916 | 7812219 | test |
1641598078261:1 | 0 | jackson | eglinton | 840 | fowles street | mountview | burleigh heads | 2830 | sa | 19830807 | 2932837 | test | 1
| jackson | eglinton | 840 | fowles street | moun tvjiew | burleigh heads | 2830 | ss |  | 2932837 | test |
1641598610941:8 | 1 | jaiden | rolilns | 48 | swinden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 1
| jaiden | rollins | 48 | tulgeywood | rossarden street | balwyn north | 2224 | nt | 19280722 | 7626396 | test |
1641598078261:13 | 0 | jaiden | rolilns | 48 | swinden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 1
| jaiden | rollins | 48 | tulgeywood | rossarden street | balwyn north | 2224 | nt | 19280722 | 7626396 | test |
1641598610941:10 | 1 | benjamin | carbone | 18 | wattle street | arthella | orange | 3550 | vic | 19050820 | 3677127 | test | 1
| benjaminl | carbone | 18 | arthella | wattle s treet | orange | 3550 | vic | 19050820 | 3677127 | test |
1641598610941:0 | 1 | angus | rosa | 62 | gormanston crescent | mlc centre | kirwan | 3350 | sa | 19250817 | 2655081 | test | 1
| angus | roas | 62 | gormansto crescent | mlc centre | kiruwah | 3350 | sa | 19250817 | 2655081 | test |
1641598610941:12 | 1 | xani | green | 2 | phillip avenue | abbey green | armidale | 5108 | nsw | 19390410 | 9201057 | test | 1
| xani | green |  | phill ip avenue |  | armidale | 5108 | nsw | 19390410 | 9201057 | test |
1641598610941:2 | 1 |  | eglinton | 24 | curriecrescent | woorinyan | riverwood | 3749 | qld | 19180205 | 1909717 | test | 0
|  |  | 24 |  | woorinyan | riverwood | 3749 | qld | 19180205 | 9341716 | test |
1641598078261:5 | 0 | jackson | eglinton | 840 | fowles street | mountview | burleigh heads | 2830 | sa | 19830807 | 2932837 | test | 1
| jackson | eglinron | 840 | mountview | fowles treet | burlei gh heads | 2803 | sa | 19830807 | 2932837 | test |
1641598078261:21 | 0 | erin | maynard | 51 | wilshire street | warialda | little irver | 2777 | vic | 19970430 | 1815999 | test | 1
| erin | maynard | 24 |  | wariala | little river | 2777 | vic | 19970430 | 7429462 | test |
1641598610941:1 | 0 | nicole | shadbolt | 46 | schlich s treet | simpson army barracks | toowoomba | 3000 | wa | 19030926 | 8190756 | test | 0
| nathan | smallacombe | 20 | guthridge crescent | red cross units | sandy bay | 6056 | sa | 19241223 | 7522263 | test |
1641598610941:17 | 0 | tyler | frojd |  | burramurra avenue | kmart p plaza | san rmeo | 3670 | sa | 19800916 | 7812219 | test | 0
| thomas | george | 1 | mcmanus place | stoney creek | north turramurra | 3130 | sa | 19630225 | 5460534 | test |
1641598610941:15 | 0 | tyler | frojd |  | burramurra avenue | kmart p plaza | san rmeo | 3670 | sa | 19800916 | 7812219 | test | 0
| takeisha | freeborn | 6 | suttor street | the groves street | wentworth falls | 4615 | vic | 19620206 | 8111362 | test |
1641598610941:11 | 0 | jaiden | rollins | 48 | rossarden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 0
| jackson | eglinton | 840 | fowles street | mountv iew | burleigh heads | 2830 | sa | 19830807 | 2932837 | test |
1641598610941:5 | 0 | samantha | sabieray | 68 | quandong street | wattle brae | gorokan | 4019 | wa | 19590807 | 2863290 | test | 0
| sachin | stephenson | 81 | rose scott circuit | cordoba manor | ashfi eld | 4226 | vic | 19461101 | 4783085 | test |
1641598610941:19 | 0 | angus | roas | 62 | gormansto crescent | mlc centre | kiruwah | 3350 | sa | 19250817 | 2655081 | test | 0
| annalise | stephenson | 81 | rose scott circuit | cordoba manor | ashfoeld | 4226 | vic | 19461101 | 4783085 | test |
1641598078261:9 | 0 | giorgia | frahn | 62 | handasyde street | ramano estate locn 1 | tallebudgera | 4506 | vic | 19670206 | 9724789 | test | 0
| gianni | matson | 701 | willis street | boonooloo | clifton | 3101 | vic | 19410111 | 2540080 | test |
1641598610941:13 | 0 | jaiden | rolilns | 48 | swinden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 0
| jackson | eglinton | 840 | fowles street | mountv iew | burleigh heads | 2830 | sa | 19830807 | 2932837 | test |
1641598610941:3 | 0 | jaiden | rollins | 48 | tulgeywood | rossarden street | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 0
| jackson | eglinton | 840 | fowles street | mountv iew | burleigh heads | 2830 | sa | 19830807 | 2932837 | test |
1641598610941:9 | 0 | angus | rosa | 62 | gormanston crescent | mlc centre | kirwan | 3350 | sa | 19250817 | 2655081 | test | 0
| annalise | stephenson | 81 | rose scott circuit | cordoba manor | ashfoeld | 4226 | vic | 19461101 | 4783085 | test |
1641598078261:0 | 0 | takeisha | freeborn | 6 | suttor street | the groves street | wentworth falls | 4615 | vic | 19620206 | 8111362 | test | 0
| thomas | george | 1 | mcmanus place | stoney creek | north turramurra | 3130 | sa | 19630225 | 5460534 | test |
1641598078261:4 | 0 | tyler | froud | 8 | burramurra avenue | kmart p plaza | san remo | 3670 | sa | 19800916 | 7812219 | test | 0
| thomas | george | 1 | mcmanus place | stoney creek | north turramurra | 3130 | sa | 19630225 | 5460534 | test |
1641598078261:8 | 0 | tyler | frojd |  | burramurra avenue | kmart p plaza | san rmeo | 3670 | sa | 19800916 | 7812219 | test | 0
| thomas | george | 1 | mcmanus place | stoney creek | north turramurra | 3130 | sa | 19630225 | 5460534 | test |
1641598078261:12 | 0 | tyler | frojd |  | burramurra avenue | kmart p plaza | san rmeo | 3670 | sa | 19800916 | 7812219 | test | 0
| takeisha | freeborn | 6 | suttor street | the groves street | wentworth falls | 4615 | vic | 19620206 | 8111362 | test |
1641598078261:15 | 0 | brooklyn | naar-cafentas | 210 | duffy street | tourist psrk | berwick | 2481 | nsw |  | 3624304 | test | 0
| blake | ryan | 4 | starling place | berkeley vlge | marsden | 5412 | nsw | 19271027 | 2402765 | test |
1641598610941:7 | 0 | benjaminl | carbone | 18 | arthella | wattle s treet | orange | 3550 | vic | 19050820 | 3677127 | test | 0
| brooklyn | naar-cafentas | 210 | duffy street | tourist psrk | berwick | 2481 | nsw |  | 3624304 | test |
1641598078261:17 | 0 | jaiden | rolilns | 48 | swinden street | tulgeywood | balwyn north | 2224 | nt | 19280722 | 7626396 | test | 0
| jackson | eglinton | 840 | fowles street | moun tvjiew | burleigh heads | 2830 | ss |  | 2932837 | test |
1641598078261:19 | 0 | keziah | painter | 18 | ainsli e avenue | sec 1 | torquay | 3205 | vic | 19191031 | 7801066 | test | 0
| kykee | turale | 81 | rose scott circuit |  | ashfield | 4226 | vic | 19461101 | 4783085 | test |
1641598078261:23 | 0 | kiandra | cowle | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 0
| keziah | painter | 18 | ainsli e avenue | sec 1 | torquay | 3205 | vic | 19191031 | 7801066 | test |
1641598078261:3 | 0 | benjamin | carbone | 18 | wattle street | arthella | orange | 3550 | vic | 19050820 | 3677127 | test | 0
| brooklyn | naar-cafentas | 210 | duffy street | tourist psrk | berwick | 2481 | nsw |  | 3624304 | test |
1641598078261:31 | 0 | kiandra | cowle | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 0
| kykee | turale | 81 | rose scott circuit |  | ashfield | 4226 | vic | 19461101 | 4783085 | test |
1641598078261:7 | 0 | kiandra |  | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 0
| keziah | painter | 18 | ainsli e avenue | sec 1 | torquay | 3205 | vic | 19191031 | 7801066 | test |
1641598078261:11 | 0 | kiandra |  | 2 | gatliff place | rustenburg sth | girgarre | 3995 | qld | 19801125 | 3328205 | test | 0
| kykee | turale | 81 | rose scott circuit |  | ashfield | 4226 | vic | 19461101 | 4783085 | test |